Module geometry

Module geometry 

Module for graphs with vertices embedded in a metric space.

Structs

IncompatiblePointsError
Error returned when two points have a different dimension.
NodeNotReachedError
Error returned when a greedy routing fails.

Functions

angular_distance
Computes the distance between the points angles1 and angles2 on the unit n-sphere, where n is the length of angles1 and angles2.
euclidean_distance
Computes the Euclidean distance between x and y.
greedy_routing
Greedy routing shortest path algorithm.
greedy_routing_success_rate
Returns the proportion of successful greedy routing paths between all pairs of nodes.
hyperboloid_hyperbolic_distance
Computes the hyperbolic distance between the points x1 and x2 in the hyperboloid model.
lp_distance
Computes the L^p distance between x and y.
maximum_distance
Computes the maximum distance (Chebyshev distance or L^infinity distance) between x and y.
polar_hyperbolic_distance
Computes the hyperbolic distance between two points in polar coordinates.