hyperboloid_hyperbolic_distance

Function hyperboloid_hyperbolic_distance 

pub fn hyperboloid_hyperbolic_distance<T: Float>(
    x: &[T],
    y: &[T],
) -> Result<T, IncompatiblePointsError>
Computes the hyperbolic distance between the points x1 and x2 in the hyperboloid model.

The “time” coordinate (opposite sign in the metric) is inferred from the others and should not be included in x1 and x2. An IncompatiblePointsError is returned when x and y have different lengths.