pub enum DijkstraEvent<N, E, K> {
    Discover(N, K),
    ExamineEdge(N, N, E),
    EdgeRelaxed(N, N, E),
    EdgeNotRelaxed(N, N, E),
    Finish(N),
}
A dijkstra search visitor event.

Variants

Discover(N, K)

This is invoked when a vertex is encountered for the first time and it’s popped from the queue. Together with the node, we report the optimal distance of the node.

ExamineEdge(N, N, E)

This is invoked on every out-edge of each vertex after it is discovered.

EdgeRelaxed(N, N, E)

Upon examination, if the distance of the target of the edge is reduced, this event is emitted.

EdgeNotRelaxed(N, N, E)

Upon examination, if the edge is not relaxed, this event is emitted.

Finish(N)

All edges from a node have been reported.