Module for graphs with vertices embedded in a metric space.
Structs
- Incompatible
Points Error - Error returned when two points have a different dimension.
- Node
NotReached Error - Error returned when a greedy routing fails.
Functions
- angular_
distance - Computes the distance between the points
angles1andangles2on the unit n-sphere, where n is the length ofangles1andangles2. - euclidean_
distance - Computes the Euclidean distance between
xandy. - greedy_
routing - Greedy routing shortest path algorithm.
- greedy_
routing_ success_ rate - Returns the proportion of successful greedy routing paths between all pairs of nodes.
- hyperboloid_
hyperbolic_ distance - Computes the hyperbolic distance between the points
x1andx2in the hyperboloid model. - lp_
distance - Computes the L^
pdistance betweenxandy. - maximum_
distance - Computes the maximum distance (Chebyshev distance or L^infinity distance) between
xandy. - polar_
hyperbolic_ distance - Computes the hyperbolic distance between two points in polar coordinates.